# Examples

Examples can be found in the ``examples`` directory. The examples are:

- `Rabi_oscillation_optimisation.py` (discussed in [quick start](getting_started.md#quick-start))
- `subclass.py` and `subclass.pyi` (discussed in the [pulse forms](pulse_forms.md) section)

[Previous](pulse_forms.md) | [Next](running_tests.md)